package org.netkernel.mod.architecture.bits;

import org.netkernel.layer0.nkf.INKFRequestContext;
import org.netkernel.layer0.nkf.INKFResponse;
import org.netkernel.layer0.representation.IHDSNode;
import org.netkernel.layer0.representation.IHDSNodeList;
import org.netkernel.layer0.representation.impl.HDSBuilder;
import org.netkernel.module.standard.endpoint.StandardAccessorImpl;
import org.netkernel.mod.architecture.MenuAccessor;
import org.netkernel.mod.architecture.Utils;

public class StaticStructureDiagramViewer extends StandardAccessorImpl
{
	public void onSource(INKFRequestContext aContext) throws Exception
	{
		IHDSNode defaults= aContext.source("arg:defaults",IHDSNode.class);
		String title=(String)defaults.getFirstValue("title");

		String url="/tools/ae/view/StaticStructureDiagram?";
		String rootHash=null;
		IHDSNodeList rootNodes=defaults.getNodes("root");
		for (IHDSNode rootNode: rootNodes)
		{	if (rootHash==null)
			{	rootHash=(String)rootNode.getValue();
			}
			url+="&root="+rootNode.getValue();
		}
		String scale=(String)defaults.getFirstValue("scale");
		if (scale==null)
		{	scale="1.0";
		}
		String decorator=(String)defaults.getFirstValue("decorator");
		String depth=(String)defaults.getFirstValue("depth");
		String lib=(String)defaults.getFirstValue("lib");
		String module=(String)defaults.getFirstValue("module");
		if (decorator!=null)
		{	url+="&decorator="+decorator;
		}
		/*
		if (scale!=null)
		{	url+="&scale="+scale;
		}
		
		if (depth==null)
		{	depth="all";
		}
		if (lib==null)
		{	lib="hide";
		}
		if (module==null)
		{	module="hide";
		}
		*/
		
		String svgId="svg"+Utils.getUniqueId();
		
		StringBuilder script=new StringBuilder();
		script.append("<!--\n");
		script.append("$('#"+svgId+"').ready(function() {");
		script.append("initLinksRaw('.el-module','gMenuModule'); ");
		script.append("initLinksRaw('.el-space','gMenuSpace'); ");
		script.append("doSVGUpdate('"+svgId+"' ); ");
		script.append("}); ");
		script.append("\n-->");
		
		HDSBuilder b=new HDSBuilder();
		b.pushNode("div");
		b.addNode("@svgId",svgId);
		if (title!=null)
		{	b.addNode("@tabtitle",title);
		}

		MenuAccessor.addExplorerTemplate(b,aContext,rootNodes.size()==1?rootHash:null,"StaticStructureDiagram",null);
		
		b.addNode("@tabicon","ui-icon-ae ui-icon-ae-ssd");
		
		b.pushNode("script",script.toString());
		b.addNode("@type","text/javascript");
		b.popNode();
		
		b.pushNode("form");
		//b.addNode("@class","form-horizontal");
		b.addNode("@id", "form"+svgId);

		b.pushNode("input");
		b.addNode("@type", "hidden");
		b.addNode("@id", svgId+"scale");
		b.addNode("@value", scale);
		b.addNode("@name", "scale");
		b.popNode();
		
		b.pushNode("div");
		b.addNode("@style", "margin:0.5em 0;");
		b.addNode("@class", "row");
		b.pushNode("div");
		b.addNode("@class", "col-sm-4");
		
			b.pushNode("div");
			b.addNode("@class","btn-group");
			
			b.pushNode("button","-");
			b.addNode("@type", "button");
			b.addNode("@class","btn btn-default");
			b.addNode("@title","smaller");
			b.addNode("@onclick", "javascript:doSmaller('"+svgId+"')");
			b.popNode();
			
			b.pushNode("button","+");
			b.addNode("@type", "button");
			b.addNode("@class","btn btn-default");
			b.addNode("@title","larger");
			b.addNode("@onclick", "javascript:doLarger('"+svgId+"')");
			b.popNode();
			
			b.pushNode("button");
			b.addNode("@type", "button");
			b.addNode("@class","btn btn-default");
			b.addNode("@title","refresh");
			b.addNode("@onclick","javascript:doSVGUpdate('"+svgId+"')");
				b.pushNode("span");
				b.addNode("@class","icon-refresh");
				b.popNode();
			b.popNode();
			
			b.pushNode("button");
			b.addNode("@type", "button");
			b.addNode("@class","btn btn-default");
			b.addNode("@title","download");
			b.addNode("@onclick","javascript:downloadSVG('"+svgId+"')");
				b.pushNode("span");
				b.addNode("@class","icon-download-alt");
				b.popNode();
			b.popNode();
			
			b.pushNode("a");
			b.addNode("@class","btn btn-default");
			b.addNode("@title","settings");
			b.addNode("@href","/tools/ae/view/editSettings");
				b.pushNode("span");
				b.addNode("@class","icon-cog");
				b.popNode();
			b.popNode();

			b.popNode();
		
		b.popNode();
		b.pushNode("div");
		b.addNode("@class", "col-sm-2");
		
			b.pushNode("select");
			b.addNode("@name", "module");
			b.addNode("@id", svgId+"module");
			b.addNode("@class","form-control");
			b.addNode("@onchange", "javascript:doSVGUpdate('"+svgId+"')");
			writeOption(b,"Hide Module","hide",module);
			writeOption(b,"Show Module","show",module);
			b.popNode();

		b.popNode();
		b.pushNode("div");
		b.addNode("@class", "col-sm-2");

			b.pushNode("select");
			b.addNode("@id", svgId+"lib");
			b.addNode("@name", "lib");
			b.addNode("@class","form-control");
			b.addNode("@onchange", "javascript:doSVGUpdate('"+svgId+"')");
			writeOption(b,"Hide Libraries","hide",lib);
			writeOption(b,"Merge Libraries","merge",lib);
			writeOption(b,"Show Libraries","show",lib);
			b.popNode();
			
		b.popNode();
		b.pushNode("div");
		b.addNode("@class", "col-sm-2");

			b.pushNode("select");
			b.addNode("@name", "depth");
			b.addNode("@id", svgId+"depth");
			b.addNode("@class","form-control");
			b.addNode("@onchange", "javascript:doSVGUpdate('"+svgId+"')");
			writeOption(b,"Depth All","all",depth);
			writeOption(b,"Module Depth","module",depth);
			writeOption(b,"Depth 1","1",depth);
			writeOption(b,"Depth 2","2",depth);
			writeOption(b,"Depth 3","3",depth);
			writeOption(b,"Depth 4","4",depth);
			writeOption(b,"Depth 5","5",depth);
			writeOption(b,"Depth 6","6",depth);
			writeOption(b,"Depth 7","7",depth);
			writeOption(b,"Depth 8","8",depth);
			writeOption(b,"Depth 9","9",depth);
			b.popNode();

		b.popNode();
		b.pushNode("div");
		b.addNode("@class", "col-sm-2");

			String shading="full";
			b.pushNode("select");
			b.addNode("@id", svgId+"shading");
			b.addNode("@name", "shading");
			b.addNode("@class","form-control");
			b.addNode("@onchange", "javascript:doSVGUpdate('"+svgId+"')");
			writeOption(b,"Full Shading","full",shading);
			writeOption(b,"No Shading","off",shading);
			b.popNode();
		
		b.popNode();

		
		b.popNode();
		b.popNode(); //row
		
		/*
		b.pushNode("input");
		b.addNode("@type","button");
		b.addNode("@value","refresh");
		b.addNode("@onclick","javascript:doSVGUpdate('"+svgId+"')");
		b.popNode();

		b.pushNode("input");
		b.addNode("@type","button");
		b.addNode("@value","download svg");
		b.addNode("@onclick","javascript:downloadSVG('"+svgId+"')");
		b.popNode();
		
		b.pushNode("a","settings");
		b.addNode("@href","/tools/ae/view/editSettings");
		b.popNode();
		*/

		b.pushNode("div");
		b.addNode("@id",svgId);
		b.addNode("@class","svgdiv");
		b.addNode("@style", "overflow: visible");
		b.addNode("@url", url);
		b.addNode("@scale", scale);
		b.popNode();
		
		IHDSNode root=b.getRoot();
		INKFResponse resp=aContext.createResponseFrom(root);
		resp.setHeader("WrappedControlPanel", title);
		resp.setHeader("WrappedControlPanelSubtitle", "Space Structure Diagram");
		resp.setHeader("WrappedControlPanelIcon", "/tools/ae/pub/images/48/Space48.png");
		resp.setHeader("WrappedControlPanelWide", true);
		
	}
	
	private static void writeOption(HDSBuilder aBuilder, String aOption, String aCurrent)
	{	aBuilder.pushNode("option",aOption);
		if (aOption.equals(aCurrent))
		{	aBuilder.addNode("@selected", "true");
		}
		aBuilder.popNode();
	}
	private static void writeOption(HDSBuilder aBuilder, String aText, String aOption, String aCurrent)
	{	aBuilder.pushNode("option",aText);
		aBuilder.addNode("@value", aOption);
		if (aOption.equals(aCurrent))
		{	aBuilder.addNode("@selected", "true");
		}
		aBuilder.popNode();
	}
}
