<?xml version="1.0" encoding="UTF-8" ?>

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xrl="http://netkernel.org/xrl">
	<xsl:output method="xml"/>
	<xsl:param name="param"/>
	<xsl:param name="resolve"/>
	
    <xsl:template match="/" >
		<div>

	<xrl:include>
		<xrl:identifier>active:controlPanelInfoBox</xrl:identifier>
		<xrl:argument name="content">
			<div>
				<p>
					The Classloader Trace Tool will search for a specific Java class in a specified module.
        </p>
        <p>
          To initiate a search, select the module to search, enter the name of the Java class
          (including the package name, for example: org.w3c.dom.Document) and then click the button labelled "Resolve".
          </p>
				<p>
					In the generated report, the top panel shows the selected module's classpath structure
					(the search order used to find a Java class).
					The second panel identifies the classloader that located and loaded the specified
					class and the third panel displays the URL used to locate the class if the class
					was generated from a static resource.
          </p>
				<p>
					The NetKernel module classloader uses the following search sequence to locate
					a class (<i>Note: this is an inversion of the search sequence used by the
					standard classloader supplied by the JRE</i>).
					<ol>
						<li>Physical root of the module</li>
						<li>
							JAR files located in the
							<i>/lib</i>
							directory of the module (indeterminate order).
						</li>
						<li>Directly from the exported classpath of any imported modules</li>
						<li>Delegated to the parent classloader - the bootloader classloader</li>
						<li>Delegated to the JVM classloader</li>
					</ol>
				</p>
			</div>
		</xrl:argument>
	</xrl:include>
	<script type="text/javascript">
	<xsl:comment>
function spaceExplorerModule()
{	hash=$("#moduleSelect").val();
	window.location='/tools/ae/view/moduleDetails/'+hash;
}	
	</xsl:comment>
	</script>
	
		
	  
	  <div class="row">
			<div class="col-md-8">
				<form method="get">
		<table class="table">
		
			<tr>
			<td class="label">Module:</td>
			<td>
			<select id="moduleSelect" name="module">
				<xsl:for-each select="/modules/module">
					<xsl:sort select="id"/>
					<option>
						<xsl:attribute name="value"><xsl:value-of select="hash"/></xsl:attribute>
						<xsl:if test="$param/hds/module/text()=hash">
							<xsl:attribute name="selected">true</xsl:attribute>
						</xsl:if>
						<xsl:value-of select="id"/> - <xsl:value-of select="version"/>
					</option>
				</xsl:for-each>
			</select>
			</td>
			</tr>
			<tr>
			<td class="label">Class:</td>
			<td>
				<input type="text" name="class" style="width: 30em;">
					<xsl:attribute name="value"><xsl:value-of select="$param/hds/class"/></xsl:attribute>
				</input>
			</td>
			</tr>
			<tr>
			<td/><td style="text-align: left;"><input value="Resolve" type="submit" class="btn btn-primary"/></td>
			</tr>
			<tr><td colspan="2"><hr/></td></tr>
			<tr ><td class="label" align="right">Module classpath:</td>
			<td class="pseudo-input">
				<div name="meta" style="overflow: auto;">
					<xsl:choose>
						<xsl:when test="$resolve/resolve/SpaceClassLoader">
							<xsl:for-each select="$resolve/resolve/SpaceClassLoader">
								<h3>Classpath Search URLs</h3>
								<xsl:for-each select="urls/url">
								<div>
									<xsl:call-template name="url">
										<xsl:with-param name="text"><xsl:value-of select="."/></xsl:with-param>
									</xsl:call-template>
								</div>
								</xsl:for-each>
								<h3>Imported ClassLoaders</h3>
								<xsl:for-each select="imports/import">
								<div><xsl:value-of select="."/></div>
								</xsl:for-each>
								<h3>Parent ClassLoader Chain</h3>
								<xsl:for-each select="parent">
								<div><xsl:value-of select="toString"/></div>
								</xsl:for-each>
							</xsl:for-each>
						</xsl:when>
						<xsl:otherwise>&#160;</xsl:otherwise>
					</xsl:choose>
				</div>
			</td>
			</tr>
			<tr><td class="label">Resolved ClassLoader:</td>
			<td >
				<div class="pseudo-input">
					<xsl:choose>
						<xsl:when test="$resolve/resolve/classloader"><xsl:value-of select="$resolve/resolve/classloader"/>
						</xsl:when>
						<xsl:when test="$resolve/resolve/classloaderError"><pre><xsl:value-of select="$resolve/resolve/classloaderError"/></pre></xsl:when>
						<xsl:otherwise><div class="bad">no class found</div></xsl:otherwise>
					</xsl:choose>
				</div>
			</td>
			</tr>
			<tr><td class="label">Resolved URL:</td>
			<td >
				<div class="pseudo-input">
					<xsl:choose>
						<xsl:when test="$resolve/resolve/url">
							<xsl:call-template name="url">
								<xsl:with-param name="text"><xsl:value-of select="$resolve/resolve/url"/></xsl:with-param>
							</xsl:call-template>
						</xsl:when>
						<xsl:when test="$resolve/null">&#160;</xsl:when>
						<xsl:otherwise><div class="bad">no URL found</div></xsl:otherwise>
					</xsl:choose>
				</div>
			</td>
			</tr>
			</table>
		</form>
			</div>
			<div class="col-md-4">
				<div class="pull-right panel panel-default">
				  	<div class="panel-heading">
				  		<div class="panel-title"><img src="/tools/ae/pub/icon.png" style="width: 24px; margin-right: 5px;"/>Explore</div>
				  	</div>
				  	<div>
				  	<a class="btn btn-default" href="javascript:spaceExplorerModule();" style="margin: 2px;">View Module</a>
				  	</div>
				  </div>
			</div>
	</div>
	  
		
		</div>
		
    </xsl:template>

	<xsl:template name="url">
		<xsl:param name="text"/>
		<xsl:choose>
			<xsl:when test="contains($text,'/')">
				<xsl:value-of select="substring-before($text,'/')"/>
				<xsl:text>/ </xsl:text>
				<xsl:call-template name="url">
					<xsl:with-param name="text" select="substring-after($text,'/')"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$text"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet> 
