package tools.explorer;

import java.util.*;

import org.netkernel.container.IKernel;
import org.netkernel.ext.system.representation.IRepDeployedModules;
import org.netkernel.layer0.nkf.INKFRequest;
import org.netkernel.layer0.nkf.INKFRequestContext;
import org.netkernel.layer0.representation.IHDSNode;
import org.netkernel.layer0.representation.IHDSNodeList;
import org.netkernel.layer0.representation.impl.HDSFactory;
import org.netkernel.layer0.representation.impl.HDSPredicateFactory;
import org.netkernel.layer0.urii.SimpleIdentifierImpl;
import org.netkernel.layer0.util.RequestBuilder;
import org.netkernel.layer0.util.RequestBuilder.Arguments;
import org.netkernel.request.IRequestScopeLevel;
import org.netkernel.request.impl.RequestScopeLevelImpl;
import org.netkernel.urii.ISpace;
import org.netkernel.urii.impl.Version;
import org.w3c.dom.Document;

public class ExplorerPluginsRepresentation
{
	private final Map<String, IHDSNode> mPhysicalEndpointViews = new HashMap<String, IHDSNode>();
	
	public ExplorerPluginsRepresentation(IHDSNode aConfig)
	{	
		
		IHDSNodeList spaces=aConfig.getNodes("/spaces/space").filter(HDSPredicateFactory.hasChild("plugins"));
		for(IHDSNode spaceNode : spaces)
		{	String space=spaceNode.getFirstValue("id").toString().trim();
			String version=spaceNode.getFirstValue("version").toString().trim();
			IHDSNode pluginsNode=spaceNode.getFirstNode("plugins");
			for (IHDSNode pluginNode: pluginsNode.getChildren())
			{	
				if (pluginNode.getFirstValue("type").equals("PhysicalEndpointViewer"))
				{	String protoId=(String)pluginNode.getFirstValue("prototype");
					mPhysicalEndpointViews.put(protoId, pluginNode);
				}
			}
		}
		
	}
	
	public Object generatePhysicalEndpointView(INKFRequestContext aContext, IRepDeployedModules aDeployedModules, String aProtoHash, String aEpHash) throws Exception
	{	
		Object result=null;
		int i=aProtoHash.lastIndexOf('/');
		String protoId=aProtoHash.substring(i+1);
		IHDSNode plugin = mPhysicalEndpointViews.get(protoId);
		if (plugin!=null)
		{	IHDSNode request = plugin.getFirstNode("request");
			Document domReq=HDSFactory.toDOM(request, true);
			IKernel k=aContext.getKernelContext().getKernel();
			RequestBuilder b = new RequestBuilder(domReq, k.getLogger());
			Arguments args=new Arguments();
			Object ep=aDeployedModules.componentForHash(aEpHash);
			args.addArgumentByValue("arg:endpoint", ep);
			INKFRequest req=b.buildRequest(aContext, args, null);
			IHDSNode spaceNode=plugin.getParent().getParent();
			String spaceId=(String)spaceNode.getFirstValue("id");
			String spaceVersion=(String)spaceNode.getFirstValue("version");
			Version v=new Version(spaceVersion);
			ISpace space=k.getSpace(new SimpleIdentifierImpl(spaceId), v, v);
			IRequestScopeLevel scope=RequestScopeLevelImpl.createOrphanedRootScopeLevel(space, aContext.getKernelContext().getRequestScope());
			req.setRequestScope(scope);
			result=aContext.issueRequest(req);
		}
		return result;
	}
}
