<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xalan="http://xml.apache.org/xalan" xmlns:nk="http://1060.org">
    <xsl:output method="xml"/>
    <xsl:variable name="imgbase">/tools/introspect/pub/</xsl:variable>
    
    <xsl:param name="httpParam"/>
    <xsl:param name="records"/>
	
	<xsl:template match="/">
		<div>
			<script language="javascript"><xsl:comment>
				function resetOffset()
				{	document.form.offset.value="0";
					document.form.submit();
				}
			</xsl:comment></script>
			<style type="text/css"><![CDATA[
				.lp { padding: 0 0.25em 0 0.25em; }
			]]></style>
			<form name="form" method="get">
				<table class="form-table">
					<tr><td class="label">Log:</td>
						<td>
							<select name="log" onChange="resetOffset()">
								<xsl:for-each select="/logs/log[string-length(file)>0]">
									<option value="{id}">
										<xsl:if test="$httpParam/hds/log=id">
											<xsl:attribute name="selected"/>
										</xsl:if>
										<xsl:value-of select="name"/>
									</option>
								</xsl:for-each>
							</select>
						</td>
					<td class="label">Page Size:</td>
					<td>
						<input type="text" name="records" size="4">
							<xsl:attribute name="value">
								<xsl:choose>
									<xsl:when test="$httpParam/hds/records">
										<xsl:value-of select="$httpParam/hds/records"/>
									</xsl:when>
									<xsl:otherwise>20</xsl:otherwise>
								</xsl:choose>
							</xsl:attribute>
						</input>
					</td>
					<td>
						<input type="hidden" name="offset">
							<xsl:attribute name="value">
								<xsl:choose>
									<xsl:when test="$httpParam/hds/offset">
										<xsl:value-of select="$httpParam/hds/offset"/>
									</xsl:when>
									<xsl:otherwise>0</xsl:otherwise>
								</xsl:choose>
							</xsl:attribute>
						</input>
						<input type="submit" value="update" class="btn"/>
					</td>
					</tr>
					<xsl:if test="$records">
						<tr>
							<td colspan="2">
								<input type="image" src="{$imgbase}start.png" name="end" title="start page" alt="start page">
									<xsl:if test="$httpParam/hds/offset=0">
										<xsl:attribute name="disabled"/>
										<xsl:attribute name="src"><xsl:value-of select="$imgbase"/>start-disabled.png</xsl:attribute>
									</xsl:if>
								</input>
								<input type="image" src="{$imgbase}prev.png" name="next" title="previous page" alt="previous page">
									<xsl:if test="$httpParam/hds/offset=0">
										<xsl:attribute name="disabled"/>
										<xsl:attribute name="src"><xsl:value-of select="$imgbase"/>next-disabled.png</xsl:attribute>
									</xsl:if>
								</input>
								<input type="image" src="{$imgbase}next.png" name="prev" title="next page" alt="next page">
									<xsl:if test="$records/log/atStart">
										<xsl:attribute name="disabled"/>
										<xsl:attribute name="src"><xsl:value-of select="$imgbase"/>next-disabled.png</xsl:attribute>
									</xsl:if>
								</input>
							</td>
						</tr>
					</xsl:if>
				</table>
			</form>
			
			<xsl:if test="$records">
				<table class="table table-striped">
					<tr>
						<th/>
						<th>Time</th>
						<th>Originator</th>
						<th>Message</th>
					</tr>
						<xsl:for-each select="$records/log/record">
							<xsl:sort select="position()" data-type="number" order="descending"/>
							<xsl:call-template name="record"/>
						</xsl:for-each>
				</table>			
			</xsl:if>
			
		</div>
	</xsl:template>
	
	<xsl:template name="record">
		<tr>
			<td align="center">
			<xsl:choose>
				<xsl:when test="level='SEVERE'"><img src="{$imgbase}error.png" alt="SEVERE"/></xsl:when>
				<xsl:when test="level='WARNING'"><img src="{$imgbase}warning.png" alt="WARNING"/></xsl:when>
				<xsl:when test="level='FINEST'"><img src="{$imgbase}debug.png" alt="DEBUG"/></xsl:when>
				<xsl:otherwise><img src="{$imgbase}info.png" alt="{level}"/></xsl:otherwise>
			</xsl:choose>
			</td>
			<td><div class="lp"><xsl:value-of select="translate(date,'T','&#160;')"/></div></td>
			<td><div class="lp">
				<xsl:value-of select="class"/>
			</div></td>
			<td><div class="lp" style="white-space: pre-wrap; overflow: hidden;"><xsl:value-of select="message"/></div></td>
		</tr>
	</xsl:template>
	
	<!-- 
	<xsl:template name="tail">
		<xsl:param name="text"/>
		<xsl:choose>
			<xsl:when test="contains($text,'.')">
				<xsl:call-template name="tail">
					<xsl:with-param name="text">
						<xsl:value-of select="substring-after($text,'.')"/>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$text"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	 -->
	
</xsl:stylesheet>